@@ -158,11 +158,6 @@ def process_templates(template_path, role_data_path, output_dir,
         if network_data is None:
             network_data = []
 
-    # Set internal network index key for each network, network resources
-    # are created with a tag tripleo_net_idx
-    for idx, net in enumerate(network_data):
-        network_data[idx].update({'idx': idx})
-
     j2_excludes = {}
     j2_excludes_path = os.path.join(template_path, 'j2_excludes.yaml')
     if os.path.exists(j2_excludes_path):
@@ -394,16 +389,6 @@ def clean_templates(base_path, role_data_path, network_data_path):
         delete(krb_service_principals_path)
         delete(common_services_path)
 
-        nic_config_dir = os.path.join(base_path, 'network', 'config')
-        for sample_nic_config_dir in os.listdir(nic_config_dir):
-            delete(os.path.join(
-                    nic_config_dir, sample_nic_config_dir,
-                    '%s.yaml' % role['name'].lower()))
-            if 'deprecated_nic_config_name' in role:
-                delete(os.path.join(
-                        nic_config_dir, sample_nic_config_dir,
-                        role['deprecated_nic_config_name']))
-
 
 opts = parse_opts(sys.argv)
 
