@@ -171,8 +171,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'OctaviaWorkerLoggingSource': ['default'],
     'OvnMetadataAgentLoggingSource': ['default'],
     'PlacementLoggingSource': ['default'],
-    'SaharaApiLoggingSource': ['default'],
-    'SaharaEngineLoggingSource': ['default'],
     # There's one template that defines this
     # differently, and I'm not sure if we can
     # safely change it.
@@ -195,14 +193,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'BondInterfaceOvsOptions': ['description',
                                 'default',
                                 'constraints'],
-    # NOTE(anil): This is a temporary change and
-    # will be removed once bug #1767070 properly
-    # fixed. OVN supports only VLAN, geneve
-    # and flat for NeutronNetworkType. But VLAN
-    # tenant networks have a limited support
-    # in OVN. Till that is fixed, we restrict
-    # NeutronNetworkType to 'geneve'.
-    'NeutronNetworkType': ['description', 'default', 'constraints'],
     'KeyName': ['constraints'],
     'OVNSouthboundServerPort': ['description'],
     'ExternalInterfaceDefaultRoute': ['description', 'default'],
@@ -345,7 +335,7 @@ def validate_endpoint_map(base_map, env_map):
 
 def validate_role_name(filename):
     with open(filename, 'r') as f:
-        tpl = yaml.safe_load(f.read())
+        tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     role_data = tpl[0]
     if role_data['name'] != os.path.basename(filename).split('.')[0]:
@@ -361,7 +351,7 @@ def validate_hci_compute_services_default(env_filename, env_tpl):
     roles_filename = os.path.join(os.path.dirname(env_filename),
                                   '../roles/Compute.yaml')
     with open(roles_filename, 'r') as f:
-        roles_tpl = yaml.safe_load(f.read())
+        roles_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     for role in roles_tpl:
         if role['name'] == 'Compute':
@@ -377,7 +367,7 @@ def validate_hci_computehci_role(hci_role_filename, hci_role_tpl):
     compute_role_filename = os.path.join(os.path.dirname(hci_role_filename),
                                          './Compute.yaml')
     with open(compute_role_filename, 'r') as f:
-        compute_role_tpl = yaml.safe_load(f.read())
+        compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     compute_role_services = compute_role_tpl[0]['ServicesDefault']
     for role in hci_role_tpl:
@@ -395,7 +385,7 @@ def validate_controller_dashboard(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.safe_load(f.read())
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -408,13 +398,30 @@ def validate_controller_dashboard(filename, tpl):
     return 0
 
 
+def validate_controller_storage_nfs(filename, tpl, exclude_service=()):
+    control_role_filename = os.path.join(os.path.dirname(filename),
+                                         './Controller.yaml')
+    with open(control_role_filename, 'r') as f:
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+
+    control_role_services = control_role_tpl[0]['ServicesDefault']
+    for role in tpl:
+        if role['name'] == 'ControllerStorageNfs':
+            services = [x for x in role['ServicesDefault'] if (x not in exclude_service)]
+            if sorted(services) != sorted(control_role_services):
+                print('ERROR: ServicesDefault in %s is different from '
+                      'ServicesDefault in roles/Controller.yaml' % filename)
+                return 1
+    return 0
+
+
 def validate_hci_role(hci_role_filename, hci_role_tpl):
     role_files = ['HciCephAll', 'HciCephFile', 'HciCephMon', 'HciCephObject']
     if hci_role_filename in ['./roles/' + x + '.yaml' for x in role_files]:
         compute_role_filename = \
             os.path.join(os.path.dirname(hci_role_filename), './Compute.yaml')
         with open(compute_role_filename, 'r') as f:
-            compute_role_tpl = yaml.safe_load(f.read())
+            compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         compute_role_services = compute_role_tpl[0]['ServicesDefault']
         for role in hci_role_tpl:
@@ -453,7 +460,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         ceph_storage_role_filename = \
             os.path.join(os.path.dirname(ceph_role_filename), './CephStorage.yaml')
         with open(ceph_storage_role_filename, 'r') as f:
-            ceph_storage_role_tpl = yaml.safe_load(f.read())
+            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         ceph_storage_role_services = ceph_storage_role_tpl[0]['ServicesDefault']
         for role in ceph_role_tpl:
@@ -484,18 +491,16 @@ def validate_controller_no_ceph_role(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.safe_load(f.read())
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
         if role['name'] == 'ControllerNoCeph':
             services = role['ServicesDefault']
-            services.remove('OS::TripleO::Services::CephClient')
             services.append('OS::TripleO::Services::CephMds')
             services.append('OS::TripleO::Services::CephMgr')
             services.append('OS::TripleO::Services::CephGrafana')
             services.append('OS::TripleO::Services::CephMon')
-            services.append('OS::TripleO::Services::CephNfs')
             services.append('OS::TripleO::Services::CephRbdMirror')
             services.append('OS::TripleO::Services::CephRgw')
             if sorted(services) != sorted(control_role_services):
@@ -509,7 +514,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     with open(cmpt_filename, 'r') as f:
-        cmpt_tpl = yaml.safe_load(f.read())
+        cmpt_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     cmpt_services = cmpt_tpl[0]['ServicesDefault']
     cmpt_services = [x for x in cmpt_services if (x not in exclude_service)]
@@ -648,7 +653,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
                     os.path.exists(newfilename.replace('.yaml', '.j2.yaml')):
                     return  # Skip for now if it's templated
                 with open(newfilename, 'r') as newfile:
-                    newtmp = yaml.safe_load(newfile.read())
+                    newtmp = yaml.load(newfile.read(), Loader=yaml.SafeLoader)
                 read_all(newfilename, newtmp)
 
     read_all(filename, tpl)
@@ -1106,7 +1111,7 @@ def validate(filename, param_map):
     retval = 0
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.safe_load(f.read())
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         is_heat_template = 'heat_template_version' in tpl
 
@@ -1163,6 +1168,11 @@ def validate(filename, param_map):
                 filename.startswith('./roles/ComputeHCISriov.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
+        if filename.startswith('./roles/ControllerStorageNfs.yaml'):
+            exclude = [
+                'OS::TripleO::Services::CephNfs']
+            retval |= validate_controller_storage_nfs(filename, tpl, exclude)
+
         if filename.startswith('./roles/ControllerStorageDashboard.yaml'):
             retval |= validate_controller_dashboard(filename, tpl)
 
@@ -1294,11 +1304,11 @@ def validate_upgrade_tasks(upgrade_tasks):
 def validate_network_data_file(data_file_path):
     try:
         with open(data_file_path, 'r') as data_file:
-            data_file = yaml.safe_load(data_file.read())
+            data_file = yaml.load(data_file.read(), Loader=yaml.SafeLoader)
 
         base_file_path = os.path.dirname(data_file_path) + "/network_data.yaml"
         with open(base_file_path, 'r') as base_file:
-            base_file = yaml.safe_load(base_file.read())
+            base_file = yaml.load(base_file.read(), Loader=yaml.SafeLoader)
 
         retval = 0
         for n in base_file:
